require 'test_helper'

class V1::ReviewsControllerTest < ActionController::TestCase
  tests V1::ReviewsController
  include Devise::TestHelpers

  test 'should user review a learning object and return :created code' do
    auth_request users(:admin)
    assert learning_objects(:user_lo).id > 0
    create_review learning_objects(:user_lo)
    assert_response :created
  end

  test 'should user review a collection and return :created code' do
    auth_request users(:admin)
    create_review collections(:ufpr)
    assert_response :created
  end

  test 'should guest user review a collection and return :unauthorized code' do
    create_review collections(:ufpr)
    assert_response :unauthorized
  end

  test 'should user delete review withou permission and return :unauthorized code' do
    auth_request users(:john)
    delete :destroy, collection_id: collections(:ufpr).id, id: reviews(:collection).id
    assert_response :unauthorized
  end

  private

  def create_review(object)
    object_param_name = "#{object.class.to_s.downcase}_id".to_sym
    object_param_name = 'learning_object_id' if LearningObject == object.class
    post :create, review: {
      name: 'Test of review',
      description: 'testing',
      pros: 'my pros',
      cons: 'my cons',
      review_ratings_attributes: [
        { rating_id: ratings(:usability).id, value: 3 },
        { rating_id: ratings(:application_context).id, value: 3 },
        { rating_id: ratings(:content).id, value: 3 }
      ]
    }, object_param_name => object.id
  end
end
