require 'test_helper'

class SearchServiceTest < ActiveSupport::TestCase

  test 'fetch learning object with all search params' do
    reindex LearningObject

    service = SearchService.new(Search.new(los_complete_search), users(:john))
    assert_equal [learning_objects(:search)], service.fetch
  end

  test 'fetch all public collections' do
    reindex Collection

    service = SearchService.new(Search.new(collections_search), users(:john))
    assert_equal [collections(:ufpr)], service.fetch
  end

  test 'fetch users named john' do
    reindex User

    service = SearchService.new(Search.new(users_john_search), users(:john))
    assert_equal [users(:john), users(:one)], service.fetch
  end

  test 'autocomplete users named john' do
    reindex User

    service = SearchService.new(Search.new(users_john), users(:john))
    assert_equal users_autocomplete_hashes([users(:john),users(:one)]), service.autocomplete
  end

  private

  def los_complete_search
    default_params.merge({
      :query => 'teste', 
      :search_class => 'LearningObject', 
      :tags => ['Matemática'],
      :types => ['Imagem'], 
      :sources => ['UFPR institution']
    })
  end

  def collections_search
    default_params.merge({
      :search_class => 'Collection'
    })
  end

  def users_john_search
    default_params.merge(users_john)
  end
  
  def users_john
    {
      :query => 'John',
      :search_class => 'User'
    }
  end

  def default_params
    {
      :page => 1,
      :results_per_page => 10,
      :order => 'score'
    }
  end

  def reindex(klass)
    klass.reindex
    klass.searchkick_index.refresh
  end

  def users_autocomplete_hashes(users=[])
    hashes = []
    users.each do |user|
      hash = {}
      hash["id"] = user.id
      hash["name"] = user.name
      hash["type"] = "User"
      hash["thumbnail"] = user.avatar.url(:thumb)
      hashes << hash
    end
    hashes
  end

end